@@ -171,7 +171,7 @@ class AgentCrewApplication:
         return None
 
     def setup_services(
-        self, provider: str, memory_llm: Optional[str] = None
+        self, provider: str, memory_llm: Optional[str] = None, need_memory: bool = True
     ) -> Dict[str, Any]:
         """
         Initialize and configure all AgentCrew services.
@@ -208,16 +208,19 @@ class AgentCrewApplication:
         except Exception as e:
             click.echo(f"⚠️  Could not restore last used model: {e}")
 
-        if memory_llm:
-            memory_service = ChromaMemoryService(
-                llm_service=llm_manager.initialize_standalone_service(memory_llm)
-            )
-        else:
-            memory_service = ChromaMemoryService(
-                llm_service=llm_manager.initialize_standalone_service(provider)
-            )
+        memory_service = None
+        context_service = None
+        if need_memory:
+            if memory_llm:
+                memory_service = ChromaMemoryService(
+                    llm_service=llm_manager.initialize_standalone_service(memory_llm)
+                )
+            else:
+                memory_service = ChromaMemoryService(
+                    llm_service=llm_manager.initialize_standalone_service(provider)
+                )
 
-        context_service = ContextPersistenceService()
+            context_service = ContextPersistenceService()
         clipboard_service = ClipboardService()
 
         try:
@@ -283,7 +286,7 @@ class AgentCrewApplication:
     def setup_agents(
         self,
         services: Dict[str, Any],
-        config_path: Optional[str] = None,
+        config_uri: Optional[str] = None,
         remoting_provider: Optional[str] = None,
         model_id: Optional[str] = None,
     ) -> AgentManager:
@@ -292,7 +295,7 @@ class AgentCrewApplication:
 
         Args:
             services: Dictionary of services
-            config_path: Path to agent configuration file
+            config_uri: Path to agent configuration file or url
             remoting_provider: Provider for remoting mode
             model_id: Model ID for remoting mode
 
@@ -315,17 +318,17 @@ class AgentCrewApplication:
 
         llm_service = services["llm"]
 
-        if config_path:
-            os.environ["SW_AGENTS_CONFIG"] = config_path
+        if config_uri:
+            os.environ["SW_AGENTS_CONFIG"] = config_uri
         else:
-            config_path = os.getenv("SW_AGENTS_CONFIG")
-            if not config_path:
-                config_path = "./agents.toml"
-            if not os.path.exists(config_path):
+            config_uri = os.getenv("SW_AGENTS_CONFIG")
+            if not config_uri:
+                config_uri = "./agents.toml"
+            if not os.path.exists(config_uri):
                 click.echo(
-                    f"Agent configuration not found at {config_path}. Creating default configuration."
+                    f"Agent configuration not found at {config_uri}. Creating default configuration."
                 )
-                os.makedirs(os.path.dirname(config_path), exist_ok=True)
+                os.makedirs(os.path.dirname(config_uri), exist_ok=True)
 
                 default_config = f"""
 [[agents]]
@@ -335,12 +338,12 @@ system_prompt = '''{DEFAULT_PROMPT}'''
 tools = ["memory", "browser", "web_search", "code_analysis"]
 """
 
-                with open(config_path, "w+", encoding="utf-8") as f:
+                with open(config_uri, "w+", encoding="utf-8") as f:
                     f.write(default_config)
 
-                click.echo(f"Created default agent configuration at {config_path}")
+                click.echo(f"Created default agent configuration at {config_uri}")
 
-        agent_definitions = AgentManager.load_agents_from_config(config_path)
+        agent_definitions = AgentManager.load_agents_from_config(config_uri)
 
         for agent_def in agent_definitions:
             if agent_def.get("base_url", ""):
@@ -416,18 +419,6 @@ tools = ["memory", "browser", "web_search", "code_analysis"]
                     f"⚠️ Unknown agent: {first_agent_name}. Using default agent. Available agents: {available_agents}"
                 )
 
-    def cleanup_old_memories(self, services: Dict[str, Any], months: int = 1) -> None:
-        if "memory" in services and services["memory"]:
-            # Clean up old memories (older than 1 month)
-            try:
-                removed_count = services["memory"].cleanup_old_memories(months=months)
-                if removed_count > 0:
-                    click.echo(
-                        f"🧹 Cleaned up {removed_count} old conversation memories"
-                    )
-            except Exception as e:
-                click.echo(f"⚠️ Memory cleanup failed: {str(e)}")
-
     def run_console(
         self,
         provider: Optional[str] = None,
@@ -466,8 +457,6 @@ tools = ["memory", "browser", "web_search", "code_analysis"]
             self.setup_agents(services, agent_config)
             self.restore_last_agent()
 
-            self.cleanup_old_memories(services, months=1)
-
             # Create the message handler
             message_handler = MessageHandler(
                 services["memory"], services["context_persistent"], with_voice
@@ -531,8 +520,6 @@ tools = ["memory", "browser", "web_search", "code_analysis"]
             self.setup_agents(services, agent_config)
             self.restore_last_agent()
 
-            self.cleanup_old_memories(services, months=1)
-
             # Create the message handler
             message_handler = MessageHandler(
                 services["memory"], services["context_persistent"], with_voice
@@ -753,7 +740,7 @@ tools = ["memory", "browser", "web_search", "code_analysis"]
                         "No LLM API key found. Please set either ANTHROPIC_API_KEY, GEMINI_API_KEY, OPENAI_API_KEY, GROQ_API_KEY, or DEEPINFRA_API_KEY"
                     )
 
-            services = self.setup_services(provider, memory_llm)
+            services = self.setup_services(provider, memory_llm, need_memory=False)
 
             if mcp_config:
                 os.environ["MCP_CONFIG_PATH"] = mcp_config
