@@ -6,6 +6,7 @@ Refactored to use separate modules for different responsibilities.
 from __future__ import annotations
 import asyncio
 import time
+import signal
 from typing import Any
 from rich.console import Console
 from rich.text import Text
@@ -53,23 +54,22 @@ class ConsoleUI(Observer):
         self.voice_recording = False
         self.message_handler.attach(self)
 
+        self._is_resizing = False
+        signal.signal(signal.SIGWINCH, self._handle_terminal_resize)
+
         self.console = Console()
         self._last_ctrl_c_time = 0
         self.latest_assistant_response = ""
         self.session_cost = 0.0
 
         # Initialize component handlers
-        self.display_handlers = DisplayHandlers(self.console)
-        self.tool_display = ToolDisplayHandlers(self.console)
-        self.input_handler = InputHandler(
-            self.console, self.message_handler, self.display_handlers
-        )
-        self.ui_effects = UIEffects(self.console, self.message_handler)
-        self.confirmation_handler = ConfirmationHandler(self, self.input_handler)
-        self.conversation_handler = ConversationHandler(
-            self.console, self.display_handlers
-        )
-        self.command_handlers = CommandHandlers(self.console, self.message_handler)
+        self.display_handlers = DisplayHandlers(self)
+        self.tool_display = ToolDisplayHandlers(self)
+        self.ui_effects = UIEffects(self)
+        self.input_handler = InputHandler(self)
+        self.confirmation_handler = ConfirmationHandler(self)
+        self.conversation_handler = ConversationHandler(self)
+        self.command_handlers = CommandHandlers(self)
 
     def listen(self, event: str, data: Any = None):
         """
@@ -283,6 +283,29 @@ class ConsoleUI(Observer):
         else:
             self.console.print(Text("\n! No text to copy.", style=RICH_STYLE_YELLOW))
 
+    def _handle_terminal_resize(self, signum, frame):
+        """
+        Signal handler for SIGWINCH.
+        This function is called when the terminal window is resized.
+        """
+        import os
+        import time
+
+        if self.input_handler.is_message_processing and self._is_resizing:
+            return  # Ignore resize during message processing
+        self._is_resizing = True
+        time.sleep(0.3)  # brief pause to allow resize to complete
+        os.system("cls" if os.name == "nt" else "printf '\033c'")
+        self.display_handlers.display_loaded_conversation(
+            self.message_handler.streamline_messages, self.message_handler
+        )
+        self.display_handlers.print_prompt_prefix(
+            self.message_handler.agent.name,
+            self.message_handler.agent.get_model(),
+            self.message_handler.tool_manager.get_effective_yolo_mode(),
+        )
+        self._is_resizing = False
+
     def start_streaming_response(self, agent_name: str):
         """Start streaming the assistant's response."""
         self.ui_effects.start_streaming_response(agent_name)
